body{
    font-family:"Microsoft Yahei";
    padding: 50px;
    color:#191919;
    background-color:#3a8cc8
}

div{
    padding: 0.5em;
}
input{
    padding: 4px 10px;
    height: 20px;
    line-height: 20px;
    position: relative;
    color: #888;
    background: #fafafa;
    border: 1px solid #ddd;
    border-radius: 4px;
    overflow: hidden;
    display: inline-block;
    margin-left:0.5em;
}
button{
    width: 140px;
    line-height: 38px;
    text-align: center;
    font-weight: bold;
    color: #fff;
    text-shadow:1px 1px 1px #333;
    border-radius: 5px;
    position: relative;
    overflow: hidden;
    cursor:pointer;
    border:1px solid #1d4f7d;
    box-shadow: 0 1px 2px #6593b1 inset,0 -1px 0 #2c415b inset,0 -2px 3px #628db2 inset;
    background: -webkit-linear-gradient(top,#307aa4,#206084);
    background: -moz-linear-gradient(top,#307aa4,#206084);
    background: linear-gradient(top, #307aa4, #206084);
    margin-left: 4em;
}
label{
    width:4em;
}
.title{
    text-align:center;
  color:white;
  font-weight:bold;
    font-size:22px
}
.box {
    background-color:white;
    text-align: center;
    border-radius:50px;
    -moz-border-radius:50px;
    -webkit-border-radius:50px;
    box-shadow:inset 0 5px 10px -5px #191919,0 1px 0 0 #444;
    -moz-box-shadow:inset 0 5px 10px -5px #191919,0 1px 0 0 #444;
    padding: 2em;
    -webkit-box-shadow:inset 0 5px 10px -5px #191919,0 1px 0 0 #444
}
.main{
/*        display:none */
}
.row{
  padding-left: 4em;
  text-align: left;
  height:2em;
  padding-bottom: 1px
}

#autologin{
  position: relative;
  top: 5px;
}

.msg{
  color:red;
  font-style:italic;
  text-align: left;
  padding-top: 2px;
  padding-left: 4em;
}
.bottom{
  text-align: center;
  bottom:40px;
  position: absolute;
  width:30em
}
input[type=checkbox]{
  width: 1.2em;
}
.info{
  color: #4c8e0e;
  font-weight:normal;
  font-size: 14px;
}
